Author: Obsidian
Description: آشنایی با افزونه Bases برای ایجاد نمای پایگاه‌داده از یادداشت‌ها

# معرفی Bases در Obsidian

## مقدمه

Bases یک افزونه‌ی اصلی است که به شما اجازه می‌دهد نمایی شبیه پایگاه‌داده از یادداشت‌هایتان بسازید. با استفاده از یک base می‌توانید فایل‌ها و ویژگی‌هایشان را مشاهده، ویرایش، مرتب‌سازی و فیلتر کنید. این قابلیت می‌تواند به شما کمک کند تا هر چیزی از پروژه‌ها گرفته تا برنامه‌های سفر، فهرست کتاب‌های خواندنی و موارد دیگر را سازمان‌دهی کنید.

هر base می‌تواند چندین نما (view) با چیدمان‌های مختلف مانند جدول (table) و کارت (card) داشته باشد. در تصویر زیر نمونه‌ای از نمای جدولی را می‌بینید که در آن هر ردیف نمایانگر یک فایل است و هر ستون یکی از ویژگی‌های آن فایل را نشان می‌دهد.